function [t, y] = solve_euler1d(f, tBereich, y0, h)
% Integration der eindimensionalen DGL
%    y' = f(y, t)
% mit der Eulerformel.
%   Argumente
%       Funktion f
%       Zeitintervall [tStart tEnd]
%       Startwert y(0) = y0
%       Schrittweite h
%   Ergebnis
%     Spaltenvektor t mit Zeitwerten
%     Spaltenvektor y mit Naeherungsloesung y(t)
  t0 = tBereich(1);          % Anfangszeit
  t1 = tBereich(2);          % Endzeit
  N = ceil((t1 - t0)/h) + 1; % Zahl der Zeitpunkte
  y = zeros(N,1);            % Vektoren fuer die Loesung
  t = zeros(N,1);
  y(1) = y0;
  t(1) = t0;
  for I = 2:N
    y(I) = y(I-1) + h*f(t(I-1), y(I-1));
    t(I) = t(I-1) + h;
  end
end
